import {
  Datasource,
  IEventParam,
  Metadata,
  Http,
  I18n,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import {
  Button,
  GridEditable,
  AlertService,
} from '@zeedhi/common';

export class StructureAndPercentualPerItemOperationalController {
  private departmentCurrentRow: any = {};
  
  private employeeCurrentRow: any = {};
  
  public isNotUpdateRowEditing = true;

  public onInlineEditUpdateRow({ component }: IEventParam<GridEditable>) {
    this.isNotUpdateRowEditing = !component.editing;
  }

  public async cancelEditingUpdateRow({ component }: IEventParam<Button>) {
    const grid = component.parent as GridEditable;
    await grid.cancelEditedRows();
    this.onInlineEditUpdateRow({ component: grid });
    grid.editingNewRows = false;
  }

  public async saveEditingUpdateRow({ component }: IEventParam<Button>) {
    const grid = component.parent as GridEditable;
    await grid.saveEditedRows();
    this.onInlineEditUpdateRow({ component: grid });
    grid.editingNewRows = false;
  }
  
  public updateAlterationUnitItem({ component }: any) {
    const grid = Metadata.getInstance<TekGrid>('gridItens');
    const comp = component;
    const sendObject = {
      NRSEQITEMORCA: grid.datasource.currentRow.NRSEQITEMRCA,
      VRPERCITEMGOP: grid.datasource.currentRow.VRPERCITEMGOP,
      CDFILIAL: grid.datasource.currentRow.CDFILIAL,
    };
    try {
      Http.post('/updateAlterationUnitItem', {
        requestType: 'Row',
        row: sendObject,
      });
      this.showSaveSuccessAlert();
      comp.editingNewRows = false;
    } catch (e) {
      this.showSaveFailedAlert();
    }
  }
  
  public rowClick({ component }: any) {
    const text: string[] = [];
    const grid = Metadata.getInstance<TekGrid>('gridItens');
    grid.datasource.setFilter({
      CDFILIAL: component.datasource.currentRow.CDFILIAL,
    });
    text.push(`<h3>Unidade: ${component.datasource.currentRow.CDFILIAL} - ${component.datasource.currentRow.NMFILIAL}</h3>`);
    component.getChildInstance('current-row').text = text;
  }
  
  public showSaveSuccessAlert() {
    AlertService.show({
      name: 'saveSucessAlert',
      text: I18n.translate('Alteração salva com sucesso.'),
      color: 'success',
      timeout: 3000,
      top: true,
      right: true,
    });
  }
  
  public showSaveFailedAlert() {
    AlertService.show({
      name: 'saveFailedAlert',
      text: I18n.translate('Verifique os campos inválidos.'),
      color: 'error',
      timeout: 5000,
      top: true,
      right: true,
    });
  }
  
  public rowClickTaxDetail({ component }: any) {
    const grid = Metadata.getInstance<TekGrid>('taxDetailItems');
    grid.datasource.setFilter({
      CDFILIAL: component.datasource.currentRow.CDFILIAL,
      NRPERCITEMGOP: component.datasource.currentRow.NRPERCITFILGOP,
    });
  }

  public onChangeDepartmentCurrentRow({ component }: IEventParam<Datasource>) {
    this.departmentCurrentRow = component.currentRow;
  }

  get hasNoDepartment() {
    return !this.departmentCurrentRow.CDFILIAL;
  }

  get hasDepartment() {
    return !!this.departmentCurrentRow.CDFILIAL;
  }

  public onChangeEmployeeCurrentRow({ component }: IEventParam<Datasource>) {
    this.employeeCurrentRow = component.currentRow;
  }
}
